@@ -23,6 +23,10 @@ bool gjs_internal_compile_internal_module(JSContext* cx, unsigned argc,
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_internal_get_registry(JSContext* cx, unsigned argc, JS::Value* vp);
 
+GJS_JSAPI_RETURN_CONVENTION
+bool gjs_internal_get_source_map_registry(JSContext* cx, unsigned argc,
+                                          JS::Value* vp);
+
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_internal_set_global_module_loader(JSContext* cx, unsigned argc,
                                            JS::Value* vp);
@@ -50,4 +54,7 @@ bool gjs_internal_load_resource_or_file_async(JSContext* cx, unsigned argc,
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_internal_uri_exists(JSContext* cx, unsigned argc, JS::Value* vp);
 
+GJS_JSAPI_RETURN_CONVENTION
+bool gjs_internal_atob(JSContext* cx, unsigned argc, JS::Value* vp);
+
 #endif  // GJS_INTERNAL_H_
